@@ -1,7 +1,7 @@
 package Data::Random::Tree;
 
-our $DATE = '2016-03-24'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -133,10 +133,10 @@ sub create_random_tree {
         }
         # connect parent with its children
         for my $i (0..$#parents) {
-            $parents[$i]->children(@{ $children[$i] });
+            $parents[$i]->children($children[$i] // []);
         }
 
-        @parents = map { @{ $children[$_] } } 0..$#parents;
+        @parents = map { @{ $children[$_] // [] } } 0..$#parents;
     }
 
     $root;
@@ -157,7 +157,7 @@ Data::Random::Tree - Create random tree
 
 =head1 VERSION
 
-This document describes version 0.02 of Data::Random::Tree (from Perl distribution Data-Random-Tree), released on 2016-03-24.
+This document describes version 0.03 of Data::Random::Tree (from Perl distribution Data-Random-Tree), released on 2016-03-26.
 
 =head1 SYNOPSIS
 
@@ -199,7 +199,7 @@ level 3 should only be C1 nodes, and so on).
 TODO: Allow setting node attributes with random values (without having the user
 use C<code_instantiate_node>).
 
-This function is not exported by default, but exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
